@@ -17,14 +17,14 @@ use Storable 3.15 'dclone';
 
 no warnings 'experimental';
 
-our $VERSION='0.02411';
+our $VERSION='0.02430';
 
 =head1 NAME
 
 Vote::Count
 
 
-=head1 VERSION 0.02411
+=head1 VERSION 0.02430
 
 =cut
 
@@ -608,13 +608,18 @@ L<Vote::Count::Start|https://metacpan.org/pod/Vote::Count::Start>
 =back
 
 
-=head3 Documentation
+=head3 Additional Documentation
 
 =over
 
 =item *
 
-L<Vote::Count::HandCount|https://metacpan.org/pod/distribution/Vote-Count/lib/Vote/Count/Method/Hand_Count.pod>
+L<Catalog|https://metacpan.org/pod/distribution/Vote-Count/lib/Vote/Catalog.pod>
+
+
+=item *
+
+L<Hand Count|https://metacpan.org/pod/distribution/Vote-Count/lib/Vote/Hand_Count.pod>
 
 
 =item *
